@@ -841,7 +841,7 @@ function ThemeNav () {
                 .attr('aria-expanded','false');
         }
         parent_li
-            .toggleClass('current')
+            .addClass('current')
             .attr('aria-expanded', function(i, old) {
                 return old == 'true' ? 'false' : 'true';
             });
@@ -979,9 +979,11 @@ $("#sphinx-template-side-scroll-right").on("click", "a.reference.internal", func
   if (href !== "#"){
     offset = $(href).offset().top - utilities.getFixedOffset()
   }
-  $('html').stop().animate({scrollTop: offset}, 850, function (){
+  prev_offset = $(window).scrollTop()
+  if (Math.abs(offset - prev_offset) < 10)
     link.children("button").trigger("click");
-  });
+  else
+    $('html').stop().animate({scrollTop: offset}, 850);
   e.preventDefault();
   e.stopPropagation();
 });
@@ -998,6 +1000,7 @@ for (var i = 0; i < menuItems.length; i++) {
   }
 }
 
+ArticleItems = $(Object.keys(scrollItems).join(', '))
 findParent = function(item) {
   return $(item).parent().parent().siblings("a.reference.internal")
 },
@@ -1023,42 +1026,22 @@ showHighlight = function(item) {
   sideMenus.expandClosestUnexpandedParentList(item);
 },
 initHighlight = function() {
-  item_list = $(Object.keys(scrollItems).join(', '))
-  if (item_list.length) {
+  if (ArticleItems.length) {
     var value = -1e10;
     var idx = -1;
-    for (var i = 0; i < item_list.length; i++) {
-      var offset = $(item_list[i]).offset().top - $(window).scrollTop() - utilities.getFixedOffset();
+    for (var i = 0; i < ArticleItems.length; i++) {
+      var offset = $(ArticleItems[i]).offset().top - $(window).scrollTop() - utilities.getFixedOffset();
       if (offset <= 50 && offset > value) {
         value = offset;
         idx = i;
       }
     }
     if (idx !== -1) {
-      showHighlight(scrollItems['#' + item_list[idx].id.replaceAll('.', '\\.')])
+      showHighlight(scrollItems['#' + ArticleItems[idx].id.replaceAll('.', '\\.')])
     }
   }
 };
-
-$(window).scroll(function() {
-  $(Object.keys(scrollItems).join(', ')).each(function () {
-    var offsetScroll = $(this).offset().top - $(window).scrollTop() - utilities.getFixedOffset();
-    if (offsetScroll <= 30 && offsetScroll >= -30) {
-      var menu_item = scrollItems['#' + this.id.replaceAll('.', '\\.')]
-      if (!$(menu_item).hasClass("side-scroll-highlight")){
-        showHighlight(menu_item)
-      }
-      else if (!$(menu_item).hasClass("current")) {
-        $(menuItems).removeClass("current");
-        $(menu_item).addClass("current")
-        var item_list = menu_item.nextElementSibling
-        $(item_list).find("a.reference.internal").removeClass("side-scroll-highlight");
-        $(item_list).find("ul").attr('display', 'none').attr('aria-expanded', 'false');
-      }
-    }
-  });
-});
-
+$(window).scroll(initHighlight);
 $(document).ready(initHighlight);
 $(window).on('hashchange', initHighlight);
 
